==> qsa-x11-free-1.1.1.tar.gz: qsa-x11-free-1.1.1/src/engine/qsfuncref.h <==
/****************************************************************************
** $Id: qsfuncref.h  1.1.1   edited 2003-06-20T21:19:30$
**
** Copyright (C) 2001-2003 Trolltech AS.  All rights reserved.
**
** This file is part of the Qt Script for Applications framework (QSA).
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding a valid Qt Script for Applications license may use
** this file in accordance with the Qt Script for Applications License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about QSA Commercial License Agreements.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
*****************************************************************************/

#ifndef QSFUNCREF_H
#define QSFUNCREF_H

#include "qsclass.h"

class QSFuncRefClass : public QSSharedClass {
public:
    QSFuncRefClass( QSClass *b ) : QSSharedClass( b, AttributeExecutable ) { }
    QString name() const { return "Function"; }

    virtual QSEqualsResult isEqual( const QSObject &a, const QSObject &b ) const;

    bool toBoolean( const QSObject * ) const;
    double toNumber( const QSObject *obj ) const;
    QString toString( const QSObject * ) const;

    QSObject construct( const QSList &args ) const;
    QSObject cast( const QSList &args ) const;

    QSObject createReference( const QSObject &base, const QSMember &mem ) const;


    static QSMember refMember( const QSObject &ref );
    static ScopeChain refScope( const QSObject &ref );
    static QSObject refBase( const QSObject &ref );

protected:
    virtual QSObject invoke( QSObject * objPtr, const QSMember &mem ) const;
};

#endif

==> qsa-x11-free-1.1.2.tar.gz: qsa-x11-free-1.1.2/src/engine/qsfuncref.h <==
/****************************************************************************
** $Id: qsfuncref.h  1.1.2   edited 2005-01-14T15:17:03$
**
** Copyright (C) 2001-2003 Trolltech AS.  All rights reserved.
**
** This file is part of the Qt Script for Applications framework (QSA).
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding a valid Qt Script for Applications license may use
** this file in accordance with the Qt Script for Applications License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about QSA Commercial License Agreements.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
*****************************************************************************/

#ifndef QSFUNCREF_H
#define QSFUNCREF_H

#include "qsclass.h"

class QSFuncRefClass : public QSSharedClass {
public:
    QSFuncRefClass( QSClass *b ) : QSSharedClass( b, AttributeExecutable ) { }
    QString name() const { return QString::fromLatin1("Function"); }

    virtual QSEqualsResult isEqual( const QSObject &a, const QSObject &b ) const;

    bool toBoolean( const QSObject * ) const;
    double toNumber( const QSObject *obj ) const;
    QString toString( const QSObject * ) const;

    QSObject construct( const QSList &args ) const;
    QSObject cast( const QSList &args ) const;

    QSObject createReference( const QSObject &base, const QSMember &mem ) const;


    static QSMember refMember( const QSObject &ref );
    static ScopeChain refScope( const QSObject &ref );
    static QSObject refBase( const QSObject &ref );

protected:
    virtual QSObject invoke( QSObject * objPtr, const QSMember &mem ) const;
};

#endif
